using System.Windows;
using System.Windows.Controls.Primitives;
using System.Windows.Input;

namespace SLAttachedBehavior
{
    public static class MouseMove
    {
        private static readonly DependencyProperty MouseMoveCommandBehaviorProperty = DependencyProperty.RegisterAttached(
            "MouseMoveCommandBehavior",
            typeof(ButtonBaseMouseMoveCommandBehavior),
            typeof(MouseMove),
            null);

        public static readonly DependencyProperty CommandProperty = DependencyProperty.RegisterAttached(
            "Command",
            typeof(ICommand),
            typeof(MouseMove),
            new PropertyMetadata(OnSetCommandCallback));

        public static void SetCommand(ButtonBase buttonBase, ICommand command)
        {
            buttonBase.SetValue(CommandProperty, command);
        }

        public static ICommand GetCommand(ButtonBase buttonBase)
        {
            return buttonBase.GetValue(CommandProperty) as ICommand;
        }

        private static void OnSetCommandCallback(DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            ButtonBase buttonBase = dependencyObject as ButtonBase;
            if (buttonBase != null)
            {
                ButtonBaseMouseMoveCommandBehavior behavior = GetOrCreateBehavior(buttonBase);
                behavior.Command = e.NewValue as ICommand;
            }
        }

        private static ButtonBaseMouseMoveCommandBehavior GetOrCreateBehavior(ButtonBase buttonBase)
        {
            ButtonBaseMouseMoveCommandBehavior behavior = buttonBase.GetValue(MouseMoveCommandBehaviorProperty) as ButtonBaseMouseMoveCommandBehavior;
            if (behavior == null)
            {
                behavior = new ButtonBaseMouseMoveCommandBehavior(buttonBase);
                buttonBase.SetValue(MouseMoveCommandBehaviorProperty, behavior);
            }

            return behavior;
        }
    }
}